[open-ils-commits] r9902 - in branches/acq-experiment: . Open-ILS/src/sql/Pg Open-ILS/web/js/dojo/openils Open-ILS/web/opac/skin/default/js

svn at svn.open-ils.org svn at svn.open-ils.org
Fri Jun 20 16:34:03 EDT 2008


Author: erickson
Date: 2008-06-20 16:33:58 -0400 (Fri, 20 Jun 2008)
New Revision: 9902

Modified:
   branches/acq-experiment/
   branches/acq-experiment/Open-ILS/src/sql/Pg/030.schema.metabib.sql
   branches/acq-experiment/Open-ILS/web/js/dojo/openils/User.js
   branches/acq-experiment/Open-ILS/web/opac/skin/default/js/rdetail.js
Log:
Merged revisions 9895-9898,9901 via svnmerge from 
svn://svn.open-ils.org/ILS/trunk

........
  r9895 | miker | 2008-06-20 14:00:58 -0400 (Fri, 20 Jun 2008) | 1 line
  
  use the new opac_visible flag for CN table
........
  r9896 | miker | 2008-06-20 14:08:24 -0400 (Fri, 20 Jun 2008) | 1 line
  
  typo in previous opac_visible commit
........
  r9897 | miker | 2008-06-20 14:59:48 -0400 (Fri, 20 Jun 2008) | 1 line
  
  adding some indexes that are needed for large installations -- beware the speed impact for initial batch loading!
........
  r9898 | miker | 2008-06-20 15:29:46 -0400 (Fri, 20 Jun 2008) | 1 line
  
  removing the (value) index, as large records will make Pg unhappy -- fields too large to directly index with the default Pg blocksize
........
  r9901 | erickson | 2008-06-20 16:33:36 -0400 (Fri, 20 Jun 2008) | 1 line
  
  store the ses cookie globally
........



Property changes on: branches/acq-experiment
___________________________________________________________________
Name: svnmerge-integrated
   - /trunk:1-9892
   + /trunk:1-9901

Modified: branches/acq-experiment/Open-ILS/src/sql/Pg/030.schema.metabib.sql
===================================================================
--- branches/acq-experiment/Open-ILS/src/sql/Pg/030.schema.metabib.sql	2008-06-20 20:33:36 UTC (rev 9901)
+++ branches/acq-experiment/Open-ILS/src/sql/Pg/030.schema.metabib.sql	2008-06-20 20:33:58 UTC (rev 9902)
@@ -145,6 +145,8 @@
 	value		TEXT		NOT NULL,
 	index_vector	tsvector	NOT NULL
 );
+CREATE INDEX metabib_full_rec_tag_subfield_idx ON metabib.full_rec (tag,subfield);
+--CREATE INDEX metabib_full_rec_value_idx ON metabib.full_rec (value);
 CREATE INDEX metabib_full_rec_record_idx ON metabib.full_rec (record);
 CREATE TRIGGER metabib_full_rec_fti_trigger
 	BEFORE UPDATE OR INSERT ON metabib.full_rec

Modified: branches/acq-experiment/Open-ILS/web/js/dojo/openils/User.js
===================================================================
--- branches/acq-experiment/Open-ILS/web/js/dojo/openils/User.js	2008-06-20 20:33:36 UTC (rev 9901)
+++ branches/acq-experiment/Open-ILS/web/js/dojo/openils/User.js	2008-06-20 20:33:58 UTC (rev 9902)
@@ -119,7 +119,7 @@
                     _u.getBySession(onComplete);
                     if(_u.authcookie) {
                         dojo.require('dojo.cookie');
-                        dojo.cookie(_u.authcookie, _u.authtoken);
+                        dojo.cookie(_u.authcookie, _u.authtoken, {path:'/'});
                     }
                 }
                 authReq.send();

Modified: branches/acq-experiment/Open-ILS/web/opac/skin/default/js/rdetail.js
===================================================================
--- branches/acq-experiment/Open-ILS/web/opac/skin/default/js/rdetail.js	2008-06-20 20:33:36 UTC (rev 9901)
+++ branches/acq-experiment/Open-ILS/web/opac/skin/default/js/rdetail.js	2008-06-20 20:33:58 UTC (rev 9902)
@@ -707,7 +707,7 @@
 var _statusPositions = {};
 
 //Add one td (creating a new column) to the copy summary
 //table for each holdable copy status
 
 function rdetailBuildStatusColumns() {
 
@@ -719,7 +719,7 @@
 	for( i = 0; i < cp_statuses.length; i++ ) {
 
 		var c = cp_statuses[i];
-		if( c && isTrue(c.holdable()) ) {
+		if( c && isTrue(c.opac_visible()) ) {
 			var name = c.name();
 			_statusPositions[i] = c;
 			var node = template.cloneNode(true);
@@ -707,7 +707,7 @@
 
 //Add one td (creating a new column) to the copy summary
-//table for each holdable copy status
+//table for each opac_visible copy status
 
 function rdetailBuildStatusColumns() {



More information about the open-ils-commits mailing list